@@ -111,7 +111,7 @@ class MicroDisc:
             print('Error. Either CO or CR should be zero.') 
         self.A = np.pi*a**2
         self.km = self.sign*4*self.D/(np.pi*self.a)
-        self.iLim = n*F*A*m0*self.C
+        self.iLim = n*F*self.A*m0*self.C
 
     def LSV(self, E):
         kf = self.k0*np.exp(self.alphaf*self.n*self.FRT*(E-self.E0))
